# encoding: utf-8
import datetime

import pooler
from osv import fields, osv


class SeasonalOrderpoint(osv.osv):
    _inherit = 'stock.warehouse.orderpoint'

    def min_max_qty(self, cr, uid, ids, field_names, arg, context=None):
        if context is None:
            context = {}
            
        res = {}
        for id in ids:
            res[id] = {}.fromkeys(field_names, 0.0)

        now = datetime.datetime.now()
        for op in self.browse(cr, uid, ids):
            for variation in op.seasonal_variations:
                date_start, date_end = (datetime.datetime.strptime(d, 
                                    '%Y-%m-%d') for d in (variation.date_start, 
                                                          variation.date_end))
                date_start = date_start.replace(year=now.year)
                date_end = date_end.replace(year=now.year) + \
                    datetime.timedelta(days=1)
                
                if date_start <= now <= date_end:
                    res[op.id]['product_max_qty'] = variation.maximal_qty
                    res[op.id]['product_min_qty'] = variation.minimal_qty
        return res

    _columns = {
        'seasonal_variations': 
            fields.one2many('stock.warehouse.orderpoint.variations', 
                            'orderpoint_id', u'Seasonal variation'),
        'product_min_qty': fields.function(min_max_qty, method=True, 
                            type='float', store=False, string='Min Quantity', 
                            multi='product_min_qty'),
        'product_max_qty': fields.function(min_max_qty, method=True, 
                            type='float', store=False, string='Max Quantity', 
                            multi='product_max_qty'),
    }

SeasonalOrderpoint()


class SeasonalVariation(osv.osv):
    _name = 'stock.warehouse.orderpoint.variations'
    _rec_name = 'orderpoint_id'

    _columns = {
        'date_start': fields.date(u'Date start'),
        'date_end': fields.date(u'Date end'),
        'minimal_qty': fields.float(u'Minimal quantity'),
        'maximal_qty': fields.float(u'Maximal quantity'),
        'orderpoint_id': fields.many2one('stock.warehouse.orderpoint', 
                                         'Order point'),
    }

SeasonalVariation()
